@@ -487,6 +487,17 @@ def read_raster_info(raster_filepath):
     return (xmin, ymax, RasterXSize, RasterYSize, pixel_width, projection, epsg, datatype, n_bands, imagery_extent_box)
 
 
+def clip_project_multibandraster_toextent(composite_filepath, warped_filepath, target_epsg, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
+    cmd = ["gdalwarp",
+           "-t_srs", "EPSG:{}".format(target_epsg),
+           "-te",str(xmin),str(ymin),str(xmax),str(ymax),
+           "-r", method,
+           "-co", "COMPRESS=DEFLATE",
+           str(composite_filepath),
+           str(warped_filepath)
+           ]
+    run_subprocess(cmd, work_dir)
+
 def reproject_multibandraster_toextent(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
 
     cmd = ["gdalwarp",
@@ -669,7 +680,7 @@ def copy_file_from_s3(s3path, dstpath, retries, timeout, sleep_time):
 #################################################################################################
 #################################################################################################
 
-def get_sitecode_aoiwkt(geom_info, aoi_epsg):
+def get_sitecode_aoiwkt(geom_info, aoi_epsg, gpkg_folder_path):
     #################### geometry extent and pixel ###############################
     log.debug("Aoi wkt kwargs {}".format(geom_info))
     if type(geom_info) == list:
@@ -677,15 +688,15 @@ def get_sitecode_aoiwkt(geom_info, aoi_epsg):
        log.debug("tiles given as list: {}".format(sitecodes))
     elif str(geom_info).endswith('.gpkg'):
        log.debug("Geo package file given as input. Finding tiles from processing gpkg files to process")
-       sitecodes, composite_sitecodes = get_sitecode_from_aoiwkt_parse(geom_info, aoi_epsg)
+       sitecodes, composite_sitecodes = get_sitecode_from_aoiwkt_parse(geom_info, aoi_epsg, gpkg_folder_path)
     elif "polygon" in geom_info.lower():
        log.debug("Extent given. Finding tiles from processing gpkg files to process")
-       sitecodes, composite_sitecodes = get_sitecode_from_aoiwkt_parse(geom_info, aoi_epsg)
+       sitecodes, composite_sitecodes = get_sitecode_from_aoiwkt_parse(geom_info, aoi_epsg, gpkg_folder_path)
     log.debug("tiles: {}".format(sitecodes))
 
     sitecode_geom_dict = {}
     for sitecode in sitecodes:
-        sitecode_geom = sitecode_extent(sitecode, aoi_epsg)
+        sitecode_geom = sitecode_extent(sitecode, aoi_epsg, gpkg_folder_path)
         sitecode_geom_dict[sitecode] = sitecode_geom
 
     log.debug("aoi: {}".format(sitecode_geom_dict))
@@ -716,8 +727,8 @@ def get_sitecode_from_aoiwkt_parse(aoi_wkt, t_srs, gpkg_folder_path):
        compositing_grid = get_grid_file(t_srs, gpkg_folder_path)
        if compositing_grid["status"] == "OK":
           log.debug("grid geopackage:{}".format(compositing_grid["output"]))
-          compositing_squares = get_composite_squares(aoi_geom, compositing_grid["output"])
-    return compositing_squares
+          sitecodes, composite_squares = get_composite_squares(aoi_geom, compositing_grid["output"])
+    return sitecodes, composite_squares
 
 
 def get_composite_squares(aoi_geom, grid_geopackage):
